import os, re



def get_files(dir_path):
    r"""
    dir_path = C:\Users\Administrator\Desktop\rsgz
    file_list = get_files(dir_path)
    返回文件列表
    """
    files_list = []
    for dirpath, dirnames, filenames in os.walk(dir_path):
        for filename in filenames:
            file = os.path.join(dirpath, filename)
            files_list.append(file)
    return files_list

def get_file_shuliang(dir_path):
    r"""
    返回所有文件数量
    """
    return len(get_files(dir_path))

def get_base_name(the_list):
    r"""
    the_list 是文件或者文件夹列表  返回最简短文件列表或者文件夹列表
    the_list = []
    new_list = get_base_name(the_list)
    """
    short_name_list = []
    for i in range(len(the_list)):
        short_name = the_list[i].split(os.sep)[-1]
        short_name_list.append(short_name)
    return short_name_list

def compare_file(dir_fu, dir_zi):
    r"""
    文件比较文件
    返回 多出的部分列表
    dir_fu = r""
    dir_zi = r""
    extra_part = compare_file(dir_fu, dir_zi)
    """
    fu_set = set(get_base_name(get_files(dir_fu)))
    zi_set = set(get_base_name(get_files(dir_zi)))
    diff = list(fu_set.difference(zi_set))
    return diff

def paixu_file(file_list, jiangxu):
    r"""
    对文件列表 进行排序
    file_list = ['1.jpg', '10.jpg', '11.jpg', '2.jpg']
    jiangxu = 1  降序
    jiangxu = 0  升序
    new_list = paixu_file(file_list, jiangxu=0) # 升序 ['1.jpg', '2.jpg', '10.jpg', '11.jpg']
    """
    if jiangxu:
        file_list.sort(key=lambda x: int(re.findall("\d+", x)[0]), reverse=True)  # 降序
    else:
        file_list.sort(key=lambda x: int(re.findall("\d+", x)[0]), reverse=False)  # 升序
    return file_list

def get_num_from_file(file_list):
    r"""
    获取文件列表中的数字
    file_list = ['32293black.jpeg', '32294blue.jpeg', '32295green.jpeg']
    new_list = get_num_from_file(file_list) # ['32293', '32294', '32295']
    """
    return list(map(lambda x: re.findall("\d+", x)[0], file_list))

def get_not_number(file_list):
    r"""
    获取文件列表中 非数字部分
    file_list = ['32293black.jpeg', '32294blue.jpeg', '32295green.jpeg']
    new_list = get_not_number(file_list)  # ['black.jpeg', 'blue.jpeg', 'green.jpeg']
    """
    return list(map(lambda x: re.findall("\D+", x)[0], file_list))

def remove_number(fu_path):
    r"""
    fu_path = r'C:\Users\Administrator\Desktop\linshi-user'
    remove_number(fu_path)
    去除父路径下的所有文件名字中的数字部分
    """
    list1 =get_files(fu_path)
    for i in list1:
        if 'png' in i or 'jpg' in i:
            fu = os.path.dirname(i)
            pic_name = i.split(os.sep)[-1]
            num = re.findall("\d+",pic_name)[0]
            new_pic_name = pic_name.replace(num,'')
            new_pic_name = os.path.join(fu,new_pic_name)
            print(new_pic_name)
            os.rename(i,new_pic_name)
    pass

def remove_str(file_list , houzhui):
    r"""
    去除文件列表对应部分字符串，不仅仅是后缀名哈  其他部分字符串都可以批量去除
    不改变原来文件
    file_list = ['black.jpeg', 'blue.jpeg', 'green.jpeg']
    new_list = remove_str(file_list , houzhui=".jpeg")
    new_list # ['black', 'blue', 'green']
    """
    return list(map(lambda x:x.replace(houzhui, ""), file_list))

def get_bianhao_yanse(file_list, houzhui):
    r"""
    参数
    file_list = ['32293black.jpeg', '32294blue.jpeg', '32295green.jpeg']
    bianhao, yanse = get_bianhao_yanse(file_list, houzhui=".jpeg")
    print(bianhao)
    print(yanse)
    """
    bianhao = get_num_from_file(file_list)
    new_list = get_not_number(file_list)
    yanse = remove_str(new_list, houzhui)
    return  bianhao, yanse

def del_pic(dir_path, geshi):
    r"""
    在目标文件夹 里面 删除指定格式图片
    dir_path = r"C:\Users\Administrator\Desktop\@2\23363-23370"
    geshi = ".png"
    del_pic(dir_path, geshi)
    """
    for i in get_files(dir_path):
        if geshi in i.split(os.sep)[-1]:
            os.remove(i)
            print("删除了 {}".format(i))



if __name__ == '__main__':
    dir_path = r"C:\Users\Administrator\Desktop\@2\23363-23370"
    geshi = ".png"
    del_pic(dir_path, geshi)


import os,time
from PIL import Image
from multiprocessing.pool import ThreadPool  # 线程池

def fangda(path_fu,size_x,size_y):
    r"""
    批量放大图片，没有格式要求
    只能是等比例放大 (x=y才放大！！！)
    size_x,size_y = 900,900
    path_fu = r"C:\Users\Administrator\Desktop\444"
    fangda(path_fu,size_x,size_y)
    """
    for dirpath, dirnames, filenames in os.walk(path_fu):
        for filename in filenames:
            pic = os.path.join(dirpath, filename)
            if '.png' in pic or '.jpeg' in pic or 'jpg' in pic:
                im = Image.open(pic)
                x1, y1 = im.size
                if x1 == y1:  # 500 500 400 400 800 800
                    if x1 != size_x and y1 != size_y:
                        print(pic, im.size)
                        img = im.resize((size_x,size_y))
                        img.save(pic, quality=100, subsampling=0)
                        print("{} 修改尺寸--->{}*{}成功！".format(pic, size_x, size_y))

def check_pic_sizex_sizey(path_fu, sizex,sizey):
    r"""
    批量检查文件夹里面的图片尺寸是否是sizex sizey
    sizex,sizey=900,900
    path_fu = r"C:\Users\Administrator\Desktop\linshi-user"
    check_pic_sizex_sizey(path_fu, sizex,sizey)
    """
    for dirpath, dirnames, filenames in os.walk(path_fu):
        for filename in filenames:
            pic = os.path.join(dirpath, filename)
            if '.png' in pic or '.jpg' in pic or '.jpeg' in pic:
                im = Image.open(pic)
                x1, y1 = im.size
                if x1 != sizex and y1 != sizey:
                    print(pic, im.size)

def png_add_beijing_to_jpg(dir1,pic_background):
    r"""
    将png图片添加背景得到jpg 图片
    芒果公司要求：请注意 这里面的 pic_background  背景图片 一定要 修改成900*900 png 格式的
    dir1 = r"C:\Users\Administrator\Desktop\xxx"
    pic_background = r"C:\Users\Administrator\Desktop\芒果代码\套图\bei2-900.png"  # 这是你定义的背景图  通常是白色墙壁 但是也可能出现其他背景图
    png_add_beijing_to_jpg(dir1,pic_background)
    """

    # 原始的贴图函数
    def tietu(logo, logo_loc_xy, pic, save_imageFile):
        # mark = Image.open(waterPic)
        with Image.open(logo).convert("RGBA") as mark:  # 打开水印
            with Image.open(pic).convert("RGBA") as picture:  # 打开原图
                layer = Image.new('RGBA', picture.size, (0, 0, 0, 0))  # 新建一个层
                layer.paste(mark, logo_loc_xy)  # 层里面贴水印  等于层和水印一条船了
                out = Image.composite(layer, picture, layer)  # 层与原图结合就行了
                out.save(save_imageFile, quality=255, subsampling=0)

    # 文件集合 # 所有文件
    def all_file(dir1):
        pic_full_set = []
        for dirpath, dirnames, filenames in os.walk(dir1):
            for filename in filenames:
                pic_full = os.path.join(dirpath, filename)
                if '.png' in str(pic_full.split(os.sep)[-1]):
                    pic_full_set.append(pic_full)
                    # print(pic_full)
        return pic_full_set

    # 开始贴图
    def tie(tu, pic_background):
        try:
            logo = tu
            logo_loc_xy = 0, 0
            pic = pic_background
            # pic = r"E:\R1\原图\beijing\bei2.png"
            save_imageFile = tu.replace(".png", '@.png')
            tietu(logo, logo_loc_xy, pic, save_imageFile)

            im = Image.open(save_imageFile)
            im = im.convert('RGB')
            xin_pic = save_imageFile.replace('@.png', '.jpg')
            im.save(xin_pic, quality=100, subsampling=0)
            os.remove(save_imageFile)
        except:
            print("{}有问题!".format(tu))

    # 所有图片生成jpg
    def start_creat(pic_full_set, pic_background):
        pool = ThreadPool(processes=10)
        for t in pic_full_set:
            pool.apply_async(func=tie, args=(t, pic_background,))
            print(t, "正在处理!")
        pool.close()
        pool.join()

    start = time.time()
    # dir1 = r"C:\Users\Administrator\Desktop\444-900"
    # pic_background = r"C:\Users\Administrator\Desktop\芒果代码\紫冰做图\bei2-900.png"  # 这是你定义的背景图  通常是白色墙壁 但是也可能出现其他背景图
    pic_full_set = all_file(dir1)
    start_creat(pic_full_set, pic_background)
    print('[info]耗时：%s' % (time.time() - start))

def remove_pic_str(path_fu, *remove_str):
    r"""
    批量去除 图片名 杂字符串
    path_fu = r"C:\Users\Administrator\Desktop\333"  # 这个文件夹里面的所有图片
    remove_str = ['-removebg-preview','_']  # 这个就是需要去除的字符串列表  元素数量任意
    remove_pic_str(path_fu, *remove_str)
    """
    for dirpath, dirnames, filenames in os.walk(path_fu):
        for filename in filenames:
            pic = os.path.join(dirpath, filename)
            if '.png' in pic or '.jpg' in pic or '.jpeg' in pic:
                # new_name = pic.split(os.sep)[-1].replace('-removebg-preview','').replace('_', ' ').title().replace('Png', 'png')
                pic_name = pic.split(os.sep)[-1]
                qian = os.path.dirname(pic)
                for str in remove_str:
                    pic_name = pic_name.replace(str, '')
                pic_name = pic_name.lower()
                new_name = os.path.join(qian,pic_name)
                os.rename(pic, new_name)
                print(new_name)


r"""
这个模块的作用 是批量更改图片和文件夹的名字
C:\Users\Administrator\Desktop\all\1\blue.jpg
C:\Users\Administrator\Desktop\all\1\green.jpg
C:\Users\Administrator\Desktop\all\1\grey.jpg
C:\Users\Administrator\Desktop\all\1\light blue.jpg
C:\Users\Administrator\Desktop\all\1\pink.jpg
C:\Users\Administrator\Desktop\all\1\purple.jpg
C:\Users\Administrator\Desktop\all\1\rose.jpg
C:\Users\Administrator\Desktop\all\1\yellow.jpg
--->
编号25415开始 改成
C:\Users\Administrator\Desktop\all\25415blue.jpg
C:\Users\Administrator\Desktop\all\25416green.jpg
C:\Users\Administrator\Desktop\all\25417grey.jpg
C:\Users\Administrator\Desktop\all\25418light blue.jpg
C:\Users\Administrator\Desktop\all\25419pink.jpg
C:\Users\Administrator\Desktop\all\25420purple.jpg
C:\Users\Administrator\Desktop\all\25421rose.jpg
C:\Users\Administrator\Desktop\all\25422yellow.jpg

大文件夹改成
25415-25422
"""
import os
import re
import shutil



def re_pic_name(path_fu, org_num):
    path_list = os.listdir(path_fu)
    path_list.sort(key=lambda x:int(x), reverse = False)  # path_list ['1', '2', '4', '5', '6', '7', '8', '9', '10', '11', '12']
    # print("path_list", path_list)

    path_list_full = [os.path.join(path_fu, i) for i in path_list] # ['C:\\Users\\Administrator\\Desktop\\all\\1', 'C:\\Users\\Administrator\\Desktop\\all\\2']
    # print("path_list_full", path_list_full)

    for i in range(len(path_list_full)):
        old_file_path= path_list_full[i]
        print("old_file_path:", old_file_path)

        # 这是老文件
        file_path = old_file_path
        old_file_path_list = [os.path.join(file_path,j) for j in os.listdir(file_path)]  # 文件全名
        print("old_file_path_list:", old_file_path_list)
        pic_len = len(old_file_path_list)

        # 这是新文件
        zen = path_list_full[i]
        m = re.findall("\d+", zen)[0]  # 会匹配所有数字
        # print("m:",m)

        # 不能保证 每个一文件夹 数字都是一位 所以需要正则表达式
        # new_file_path = path_list_full[i][:-1] + str(org_num)+"-"+str(org_num+pic_len-1)  # 文件短名
        new_file_path = path_list_full[i][:-len(str(m))] + str(org_num)+"-"+str(org_num+pic_len-1)  # 文件短名

        # 解决了 25415-25424 问题
        print("new_file_path:", new_file_path)


        # 这是新文件
        # file_path = new_file_path
        # new_file_path_list = [os.path.join(file_path, j) for j in os.listdir(file_path)]  # 文件全名

        # num_pic_i_count = 0 # 记录图片迭代位置
        for k in range(len(old_file_path_list)):
            old_pic = old_file_path_list[k]
            # print(old_pic)
            new_pic = str(org_num+k)+old_pic.split(os.sep)[-1]  # 25525red.jpg
            new_pic = os.path.join(os.path.dirname(old_pic), new_pic)
            # print("new_pic:", new_pic)
            os.rename(old_pic, new_pic)
            print("{}--->\n{}".format(old_pic, new_pic))

        os.rename(old_file_path, new_file_path)
        print("{}--->\n{}".format(old_file_path,new_file_path))
        org_num = org_num + pic_len


r"""
            #if len(k.split(os.sep)[-1])> len("20265blue.jpeg")+8:
                #print(k)
"""

# .sort()
# path_fu = r"C:\Users\Administrator\Desktop\原图"
path_fu = r"C:\Users\Administrator\Desktop\xxx\xxx"  # 这个是图片大根目录
org_num = 83000  # 这个是图片的初始值
re_pic_name(path_fu, org_num)

# 注意 我这个版本不能路径中不能出现数字  出现数字就会数据混乱！！！！


import imghdr
from rsgz.file.files import get_files

# 查看所有图片格式
def view_picture_format(pic_dir):
    r"""
    查看所有图片格式
    pic_dir = r'C:\Users\Administrator\Desktop\xxxx'
    view_picture_format(pic_dir)
    """
    # pic_dir = r'C:\Users\Administrator\Desktop\xxxx'
    pic_set = get_files(dir_path=pic_dir)
    for pic in pic_set:
        print(imghdr.what(pic), pic)

# 查看 指定 图片格式
def view_specify_picture_format(pic_dir,pic_format):
    r"""
    查看 指定 图片格式
    pic_dir = r'C:\Users\Administrator\Desktop\xxxx'
    pic_format = r"webp"
    view_specify_picture_format(pic_dir,pic_format)
    ------
    webp C:\Users\Administrator\Desktop\xxxx\杂B90\blue.jpg
    webp C:\Users\Administrator\Desktop\xxxx\杂B90\green.jpg
    webp C:\Users\Administrator\Desktop\xxxx\杂B90\purple.jpg
    webp C:\Users\Administrator\Desktop\xxxx\杂B90\wine red.jpg
    """
    # pic_dir = r'C:\Users\Administrator\Desktop\xxxx'
    pic_set = get_files(dir_path=pic_dir)
    for pic in pic_set:
        if imghdr.what(pic)==pic_format:
            print(imghdr.what(pic), pic)


if __name__ == '__main__':
    pic_dir = r'C:\Users\Administrator\Desktop\xxxx'
    pic_format = r"webp"
    view_specify_picture_format(pic_dir,pic_format)


import os



def dabao():
    pro_dir = str(input("请输入pyproject.toml文件同级目录："))
    pan_fu = pro_dir.split(os.sep)[0]

    dabao_str = r"""
执行了以下命令：
{}
cd {}
py -m build
twine upload dist/*
    """.format(pan_fu, pro_dir)

    os.system("start cmd")
    print(dabao_str)



import os, shutil
from rsgz.file.files import get_base_name




# 返回所有的目录列表
def get_dirs(dir_path):
    r"""
    返回所有的目录列表
    """
    dir_list = []
    for dirpath, dirnames, filenames in os.walk(dir_path):
        for dirname in dirnames:
            the_dir = os.path.join(dirpath, dirname)
            dir_list.append(the_dir)
    return dir_list

# 返回文件夹数量
def get_dir_shuliang(dir_path):
    r"""
    返回文件夹数量
    """
    return len(get_dirs(dir_path))

# 目录比较目录(子目录 补集)
def compare_dir(dir_fu, dir_zi):
    r"""
    目录比较目录
    返回 父列表比子列表多出的一部分  返回 多出的部分列表
    1 子列表是父列表一部分

    """
    fu_set = set(get_base_name(get_dirs(dir_fu)))
    zi_set = set(get_base_name(get_dirs(dir_zi)))
    diff = list(fu_set.difference(zi_set))

# 移动目录补集
def move_buji(dir_fu, dir_zi, move_to_dir):
    r"""
    移动一个文件夹的补集 到目标目录
    dir_fu = r'\\R1\r1\已经完成\444-900'    # 父集
    dir_zi = r'\\R1\r1\已经完成\完成'        # 子集
    move_to_dir = r'\\R1\r1\已经完成\未完成'  # 移动到
    move_buji(dir_fu, dir_zi, move_to_dir)  # 将补集移动到
    """
    fu_set = set(get_base_name(get_dirs(dir_fu)))
    zi_set = set(get_base_name(get_dirs(dir_zi)))
    diff = list(fu_set.difference(zi_set))
    if not os.path.exists(move_to_dir):
        os.mkdir(move_to_dir)
    for i in diff:
        old = os.path.join(dir_fu, i)
        # new = os.path.join(move_to_dir, i)
        shutil.move(old, move_to_dir)

# 打印目录结构
def mulu_jiegou(path, indent = 0, maxi = -1):
    '''
        按文件类型递归输出目录结构
        :param path:   str 文件路径
        :param indent: int 首次缩进空格(默认为 0，一般不用改变)
        :param maxi:   int 最大展开层数(默认为 -1，表示全部展开)
    '''
    if maxi != 0:
        try:
            lsdir = os.listdir(path)
        except PermissionError:   # 权限不够的文件  不处理
            pass
        else:
            dirs = [item for item in lsdir if os.path.isdir(os.path.join(path, item))]
            files = [item for item in lsdir if os.path.isfile(os.path.join(path, item))]
            for item in dirs:
                print(' ' * indent, '+', item)
                mulu_jiegou(os.path.join(path, item), indent + 4, maxi - 1)
            for item in files:
                print(' ' * indent, '-', item)

# 给个列表 复制列表的文件夹 到目标目录
def copytree_common_dir(the_list, fu_path, copy_to):
    r"""
    复制 fu_path 中the_list出现的目录 到 copy_to位置

    the_list 就是子文件夹 简单列表
    fu_path 是父文件夹路径  包含了子文件夹列表

    the_list = ["23377-23384","23371-23376","23363-23370"]
    fu_path = r"\\192.168.0.200\e\李江涛\图集\成品\CXCJ女士插肩长袖包臀\女士插肩长袖包臀CXCJ01"
    copy_to =r"C:\Users\Administrator\Desktop\@2"
    """
    dir_list = get_dirs(fu_path)
    for i in dir_list:
        for j in the_list:
            if i.split(os.sep)[-1] == j:
                print(i)
                shutil.copytree(i, copy_to + r"\{}".format(j))

# 文件夹命名为 1 2 3
def rename_dir_1_2_3(fu):
    r"""
    fu = r"C:\Users\Administrator\Desktop\V领长袖\V领长袖"
    rename_dir_1_2_3(fu)
    """

    num = 0
    for dirpath, dirnames, filenames in os.walk(fu):
        for dirname in dirnames:
            num = num + 1
            dir1 = os.path.join(dirpath, dirname)
            xin = os.path.join(os.path.dirname(dir1), "xxxaaaxxx" + str(num))
            # print(xin)
            os.rename(dir1, xin)
    num = 0
    for dirpath, dirnames, filenames in os.walk(fu):
        for dirname in dirnames:
            num = num + 1
            dir1 = os.path.join(dirpath, dirname)
            xin = os.path.join(os.path.dirname(dir1), str(num))
            # print(xin)
            os.rename(dir1, xin)

if __name__ == '__main__':
    # path = r"C:\Users\Administrator\Desktop\111"
    # mulu_jiegou(path, indent = 0, maxi = -1)

    fu = r"C:\Users\Administrator\Desktop\xxxx"
    rename_dir_1_2_3(fu)




from rsgz.tupian.normal import remove_pic_str

path_fu = r"C:\Users\Administrator\Desktop\xxx"  # 这个文件夹里面的所有图片
remove_str = ['_','0','1','2','3','4','5','6','7','8','9']  # 这个就是需要去除的字符串列表  元素数量任意
remove_pic_str(path_fu, *remove_str)


import os
import re
from rsgz.mulu.dirs import rename_dir_1_2_3
from rsgz.tupian.normal import remove_pic_str


# 给 图集文件夹 批量设置编号   里面的图片也设置编号
def set_bianhao(path_fu, bian_hao_start):
    r"""
    给文件夹批量设置编号
    里面的图片也设置编号
    注意：使用之前 将所有的数字都去掉

    bian_hao_start = 85000
    path_fu = r"C:\Users\Administrator\Desktop\xxxx"
    set_bianhao(path_fu, bian_hao_start)
    """

    # 这个是可以改  但是不处理一些不干净数据会报错
    def bianhao():
        r"""



        C:\Users\Administrator\Desktop\all\1\blue.jpg
        C:\Users\Administrator\Desktop\all\1\green.jpg
        C:\Users\Administrator\Desktop\all\1\grey.jpg
        C:\Users\Administrator\Desktop\all\1\light blue.jpg
        C:\Users\Administrator\Desktop\all\1\pink.jpg
        C:\Users\Administrator\Desktop\all\1\purple.jpg
        C:\Users\Administrator\Desktop\all\1\rose.jpg
        C:\Users\Administrator\Desktop\all\1\yellow.jpg
        --->
        编号25415开始 改成
        C:\Users\Administrator\Desktop\all\25415blue.jpg
        C:\Users\Administrator\Desktop\all\25416green.jpg
        C:\Users\Administrator\Desktop\all\25417grey.jpg
        C:\Users\Administrator\Desktop\all\25418light blue.jpg
        C:\Users\Administrator\Desktop\all\25419pink.jpg
        C:\Users\Administrator\Desktop\all\25420purple.jpg
        C:\Users\Administrator\Desktop\all\25421rose.jpg
        C:\Users\Administrator\Desktop\all\25422yellow.jpg

        大文件夹改成
        25415-25422
        """
        org_num  = bian_hao_start

        # 获取文件夹集合
        path_list = os.listdir(path_fu)

        # 文件夹集合排序
        path_list.sort(key=lambda x: int(x), reverse=False)  # path_list ['1', '2', '4', '5', '6', '7', '8', '9', '10', '11', '12']
        # print("path_list", path_list)

        # 拼接完整文件夹路径
        path_list_full = [os.path.join(path_fu, i) for i in path_list]  # ['C:\\Users\\Administrator\\Desktop\\all\\1', 'C:\\Users\\Administrator\\Desktop\\all\\2']
        # print("path_list_full", path_list_full)

        # 迭代每个文件夹
        for i in range(len(path_list_full)):
            old_file_path = path_list_full[i]  # 老图片 路径短名
            print("old_file_path:", old_file_path)

            # 这是老文件
            file_path = old_file_path
            old_file_path_list = [os.path.join(file_path, j) for j in os.listdir(file_path)]  # 老图片 文件全名
            print("old_file_path_list:", old_file_path_list)

            pic_len = len(old_file_path_list)

            # 这是新文件
            zen = path_list_full[i]
            m = re.findall("\d+", zen)[0]  # 会匹配所有数字
            # print("m:",m)

            # 不能保证 每个一文件夹 数字都是一位 所以需要正则表达式
            # new_file_path = path_list_full[i][:-1] + str(org_num)+"-"+str(org_num+pic_len-1)  # 文件短名
            new_file_path = path_list_full[i][:-len(str(m))] + str(org_num) + "-" + str(org_num + pic_len - 1)  # 文件短名

            # 解决了 25415-25424 问题
            print("new_file_path:", new_file_path)

            # 这是新文件
            # file_path = new_file_path
            # new_file_path_list = [os.path.join(file_path, j) for j in os.listdir(file_path)]  # 文件全名

            # num_pic_i_count = 0 # 记录图片迭代位置
            for k in range(len(old_file_path_list)):
                old_pic = old_file_path_list[k]
                # print(old_pic)
                new_pic = str(org_num + k) + old_pic.split(os.sep)[-1]  # 25525red.jpg
                new_pic = os.path.join(os.path.dirname(old_pic), new_pic)
                # print("new_pic:", new_pic)
                os.rename(old_pic, new_pic)
                print("{}--->\n{}".format(old_pic, new_pic))

            os.rename(old_file_path, new_file_path)
            print("{}--->\n{}".format(old_file_path, new_file_path))
            org_num = org_num + pic_len

    # 文件夹序号重命名 并且 排序
    rename_dir_1_2_3(path_fu)

    # 去除额外的字符串
    remove_str = ['-removebg-preview','_','0','1','2','3','4','5','6','7','8','9']  # 这个就是需要去除的字符串列表  元素数量任意
    remove_pic_str(path_fu, *remove_str)

    # 数据干净了  直接设置编号
    # bian_hao_start = 80000
    bianhao()



if __name__ == '__main__':
    bian_hao_start = 85000
    path_fu = r"C:\Users\Administrator\Desktop\xxxx"
    set_bianhao(path_fu, bian_hao_start)


r"""
批量命名文件夹为 1 2 3
"""
import os


def rename_dir_1_2_3(fu):
    r"""
    fu = r"C:\Users\Administrator\Desktop\V领长袖\V领长袖"
    rename_dir_1_2_3(fu)
    """

    num=0
    for dirpath, dirnames, filenames in os.walk(fu):
        for dirname in dirnames:
            num=num+1
            dir1 = os.path.join(dirpath, dirname)
            xin = os.path.join(os.path.dirname(dir1), "xxxaaaxxx"+str(num))
            # print(xin)
            os.rename(dir1, xin)
    num=0
    for dirpath, dirnames, filenames in os.walk(fu):
        for dirname in dirnames:
            num=num+1
            dir1 = os.path.join(dirpath, dirname)
            xin = os.path.join(os.path.dirname(dir1), str(num))
            # print(xin)
            os.rename(dir1, xin)


import random




def rand_title(the_str,n):
    r"""
    返回新的 随机字符串
    the_str = r"Feature,Gorgeous,Fresh,Hot Sale,Simple,Fashion "
    new_title = rand_title(the_str, n=3) # Gorgeous Feature Simple
    """
    the_str = the_str.replace(" ,", ",").replace(", ", ",")
    the_str_list = the_str.split(",")  # ['Feature', 'Gorgeous', 'Fresh', 'Hot Sale', 'Simple', 'Fashion ']
    random.shuffle(the_str_list)
    the_str_list = the_str_list[0:n]
    the_str = ' '.join(the_str_list).title().replace("'S", "'s")
    return the_str.replace("  "," ")


def str_to_list(the_str):
    r"""
    将字符串转化为列表
    the_str = r"Feature,Gorgeous,Fresh"
    the_list = str_to_list(the_str)  # ['Feature', 'Gorgeous', 'Fresh']
    """
    return the_str.split(",")


def list_to_str(the_list, fengefu):
    r"""
    fengefu = " "
    the_list = ["123", "aabb", "jiu_s12", "rsgz"]
    the_str = list_to_str(the_list, fengefu)  # 123 aabb jiu_s12 rsgz
    注意 列表里面不能有数字 如果有请转化为字符串格式
    """
    return fengefu.join(the_list)


if __name__ == '__main__':
    pass




r"""
下面是常见的列表操作 不想记住那些复杂的 自己自定义一个挺好记的
"""

def func_to_list(func, the_list):
    r"""
    函数作用于 列表中每个元素  返回新列表
    func=lambda x: 2 + 4 * x
    list1 = list(range(0, 18))
    the_list = func_to_list(func, list1)
    """
    new_list = list(map(func, the_list))
    return new_list

def list_remove_last_element(the_list):
    r"""
    移除最后一个列表元素
    the_list = list(range(0, 3))
    the_list = list_remove_last_element(the_list)  # [0, 1]
    """
    the_list.pop()
    return the_list

def list_remove_first_element(the_list):
    r"""
    移除第一个列表元素
    the_list = list(range(0, 3))
    the_list = list_remove_first_element(the_list)  #[1, 2]
    """
    del the_list[0]
    return the_list

def list_add_first_element(the_list, ele):
    r"""
    列表开头 添加元素
    list1 = list(range(0, 3))
    new_list = list_add_first_element(list1,"帅气")  # ['帅气', 0, 1, 2]
    """
    the_list.insert(0, ele)
    return the_list

def list_add_index_element(the_list, ele, index):
    r"""
    指定位置添加列表元素
    list1 = list(range(0, 3))
    new_list = list_add_index_element(list1,"帅气", 2)  # [0, 1, '帅气', 2]
    """
    the_list.insert(index, ele)
    return the_list

def list_fanxu(the_list):
    r"""
    the_list = [0,2,5]
    new_list = list_fanxu(the_list)  # [5, 2, 0]
    """
    return the_list[::-1]

def list_to_dict(the_list):
    r"""
    the_list = ['迪迦', '荒天帝', '萧炎']
    print(list_to_dict(the_list)) # {1: '迪迦', 2: '荒天帝', 3: '萧炎'}
    """
    dict_new = enumerate(the_list, start=1)
    return dict(dict_new)

def rand_list(the_list):
    r"""
    随机列表元素
    the_list = [1,2,3,4]
    print(rand_list(the_list))  # [2, 1, 3, 4]
    """
    import random

    random.shuffle(the_list)
    return the_list

def quchong_list(the_list):
    r"""
    列表去重 位置不变
    the_list = ['a',1, 10, 'b', 1, 3, 9, 9, 'a']
    print(quchong_list(the_list))  # ['a', 1, 10, 'b', 3, 9]
    """

    dic = {}
    dic = dic.fromkeys(the_list).keys()
    return list(dic)


if __name__ == '__main__':


    the_list = ['a',1,10, 'b', 1, 3, 9, 9, 'a']
    print(quchong_list(the_list))  # ['a', 1, 10, 'b', 3, 9]